======
pymapd
======

.. image:: https://travis-ci.org/mapd/pymapd.svg?branch=master
   :target: https://travis-ci.org/mapd/pymapd
   

.. image:: https://readthedocs.org/projects/pymapd/badge/?version=latest
   :target: http://pymapd.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status

A python `DB API`_ compliant interface for `mapd`_. See the `documentation`_ for more.

Quick Install
-------------

Packages are available on conda-forge and PyPI::

   conda install -c conda-forge pymapd

Developer builds of each commit are available on the ``pymapd`` channel (Linux only)::

   conda install -c pymapd/label/dev -c conda-forge -c gpuopenanalytics/label/dev pymapd


.. _DB API: https://www.python.org/dev/peps/pep-0249/
.. _mapd: https://www.mapd.com/
.. _mapd-core: https://github.com/mapd-core/
.. _documentation: http://pymapd.readthedocs.io/en/latest/?badge=latest
